==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var RadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeries, _super);
    function RadialLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialLineSeries.$;
        return _this;
    }
    RadialLineSeries.prototype.get_d1 = function () {
        return true;
    };
    RadialLineSeries.prototype.bx = function () {
        return new RadialLineSeriesView(this);
    };
    RadialLineSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.t7 = a;
    };
    RadialLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
    };
    RadialLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialLineSeries.prototype.kx = function (a, b) {
        _super.prototype.kx.call(this, a, b);
        var c = b;
        c.c1();
    };
    RadialLineSeries.prototype.sq = function (a, b) {
        _super.prototype.sq.call(this, a, b);
        var c = b.bv;
        var d = b.bu;
        var e = a.f;
        var f = e.count;
        var g = new List$1(Array_$type, 2, f);
        var h = 0;
        for (var i = 0; i < f; i++) {
            var j = new Array(4);
            g.add(j);
            j[0] = this.rt.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[1] = this.rt.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[2] = this.rt.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
            var k = a.f._inner[i][2];
            j[3] = this.rt.e(a.f._inner[i][0], k, c, d);
            if (k > h) {
                h = k;
            }
        }
        var l = this.getEffectiveViewport1(b);
        this.rz.a0(this, this.sb(), runOn(this, this.ri), this.sd(b), this.se(b));
        var m = false;
        var n = this.rz.b;
        if (n != null) {
            m = true;
        }
        if (m) {
            var o = new ScalerParams(0, b.bv, b.bu, this.rl.cg, l);
            this.tp(e, -1, this.s4.count, this.rl, o, b.q);
        }
        var p = b;
        var q = p.da;
        var r = p.db;
        var s = p.c9;
        this.rz.ad(q, true, false, true, false);
        this.rz.ad(r, true, false, true, false);
        this.rz.ad(s, false, true, false, false);
        s._opacity = 0.75 * this.rz.j;
        p.c2(f, g, false, this.t8, this.sx(g, f - 1, b), p.cs.b, this.ft);
    };
    RadialLineSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case RadialLineSeries.$$p[0]:
                this.mi(false);
                this.lp();
                break;
        }
    };
    RadialLineSeries.prototype.get_s7 = function () {
        return true;
    };
    RadialLineSeries.$t = markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:t8:ua', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
}(AnchoredRadialSeries));
export { RadialLineSeries };
/**
 * @hidden
 */
var RadialLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeriesView, _super);
    function RadialLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c7 = new Path();
        _this.c6 = new Path();
        _this.c8 = new Path();
        _this.c4 = new Path();
        _this.c3 = new Path();
        _this.c5 = new Path();
        _this.c0 = a;
        return _this;
    }
    RadialLineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.qd = Defaults.e;
        }
    };
    Object.defineProperty(RadialLineSeriesView.prototype, "da", {
        get: function () {
            return this.c7;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "db", {
        get: function () {
            return this.c8;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "c9", {
        get: function () {
            return this.c6;
        },
        enumerable: false,
        configurable: true
    });
    RadialLineSeriesView.prototype.c1 = function () {
        this.c7.ak = null;
        this.c6.ak = null;
        this.c8.ak = null;
        this.c4.ak = null;
        this.c3.ak = null;
        this.c5.ak = null;
        this.aq();
    };
    RadialLineSeriesView.prototype.c2 = function (a, b, c, d, e, f, g) {
        this.cw.sz.m(this.c7, this.c6, this.c8, a, b, c, d, e, f, g);
        this.aq();
    };
    RadialLineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    RadialLineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c3.ak = this.c6.ak;
        this.c4.ak = this.c7.ak;
        this.c5.ak = this.c8.ak;
        this.c4._stroke = a;
        this.c4.ac = this.e.fu + 3;
        this.c5._stroke = a;
        this.c5.ac = this.e.fu + 3;
        this.c3._fill = a;
        this.c3._opacity = 1;
    };
    RadialLineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c3);
                a.s(this.c4);
                a.s(this.c5);
            }
            else {
                a.s(this.c6);
                a.s(this.c7);
                a.s(this.c8);
            }
        }
    };
    RadialLineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.c7, "lowerShape", ["Lower", "Main"]);
        this.e.a8.exportPathData(a, this.c8, "upperShape", ["Upper"]);
        this.e.a8.exportPathData(a, this.c6, "translucentShape", ["Translucent"]);
    };
    RadialLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 3;
        this.e.gx = 1;
        this.e.gy = 4;
        this.e.e7 = false;
    };
    RadialLineSeriesView.$t = markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
}(AnchoredRadialSeriesView));
export { RadialLineSeriesView };

==> igniteui-angular-charts-14.2.0.tgz: package/esm5/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var RadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeries, _super);
    function RadialLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialLineSeries.$;
        return _this;
    }
    RadialLineSeries.prototype.get_d2 = function () {
        return true;
    };
    RadialLineSeries.prototype.bx = function () {
        return new RadialLineSeriesView(this);
    };
    RadialLineSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.ub = a;
    };
    RadialLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
    };
    RadialLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialLineSeries.prototype.k0 = function (a, b) {
        _super.prototype.k0.call(this, a, b);
        var c = b;
        c.c1();
    };
    RadialLineSeries.prototype.su = function (a, b) {
        _super.prototype.su.call(this, a, b);
        var c = b.bv;
        var d = b.bu;
        var e = a.f;
        var f = e.count;
        var g = new List$1(Array_$type, 2, f);
        var h = 0;
        for (var i = 0; i < f; i++) {
            var j = new Array(4);
            g.add(j);
            j[0] = this.rx.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[1] = this.rx.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[2] = this.rx.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
            var k = a.f._inner[i][2];
            j[3] = this.rx.e(a.f._inner[i][0], k, c, d);
            if (k > h) {
                h = k;
            }
        }
        var l = this.getEffectiveViewport1(b);
        this.r3.a0(this, this.sf(), runOn(this, this.rm), this.sh(b), this.si(b));
        var m = false;
        var n = this.r3.b;
        if (n != null) {
            m = true;
        }
        if (m) {
            var o = new ScalerParams(0, b.bv, b.bu, this.rp.cg, l);
            this.tt(e, -1, this.s8.count, this.rp, o, b.q);
        }
        var p = b;
        var q = p.da;
        var r = p.db;
        var s = p.c9;
        this.r3.ad(q, true, false, true, false);
        this.r3.ad(r, true, false, true, false);
        this.r3.ad(s, false, true, false, false);
        s._opacity = 0.75 * this.r3.j;
        p.c2(f, g, false, this.uc, this.s1(g, f - 1, b), p.cs.b, this.fv);
    };
    RadialLineSeries.prototype.l7 = function (a, b, c, d) {
        _super.prototype.l7.call(this, a, b, c, d);
        switch (b) {
            case RadialLineSeries.$$p[0]:
                this.ml(false);
                this.ls();
                break;
        }
    };
    RadialLineSeries.prototype.get_tb = function () {
        return true;
    };
    RadialLineSeries.$t = markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:uc:ue', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
}(AnchoredRadialSeries));
export { RadialLineSeries };
/**
 * @hidden
 */
var RadialLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeriesView, _super);
    function RadialLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c7 = new Path();
        _this.c6 = new Path();
        _this.c8 = new Path();
        _this.c4 = new Path();
        _this.c3 = new Path();
        _this.c5 = new Path();
        _this.c0 = a;
        return _this;
    }
    RadialLineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.qh = Defaults.e;
        }
    };
    Object.defineProperty(RadialLineSeriesView.prototype, "da", {
        get: function () {
            return this.c7;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "db", {
        get: function () {
            return this.c8;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "c9", {
        get: function () {
            return this.c6;
        },
        enumerable: false,
        configurable: true
    });
    RadialLineSeriesView.prototype.c1 = function () {
        this.c7.ak = null;
        this.c6.ak = null;
        this.c8.ak = null;
        this.c4.ak = null;
        this.c3.ak = null;
        this.c5.ak = null;
        this.aq();
    };
    RadialLineSeriesView.prototype.c2 = function (a, b, c, d, e, f, g) {
        this.cw.s3.m(this.c7, this.c6, this.c8, a, b, c, d, e, f, g);
        this.aq();
    };
    RadialLineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    RadialLineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c3.ak = this.c6.ak;
        this.c4.ak = this.c7.ak;
        this.c5.ak = this.c8.ak;
        this.c4._stroke = a;
        this.c4.ac = this.e.fw + 3;
        this.c5._stroke = a;
        this.c5.ac = this.e.fw + 3;
        this.c3._fill = a;
        this.c3._opacity = 1;
    };
    RadialLineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c3);
                a.s(this.c4);
                a.s(this.c5);
            }
            else {
                a.s(this.c6);
                a.s(this.c7);
                a.s(this.c8);
            }
        }
    };
    RadialLineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.c7, "lowerShape", ["Lower", "Main"]);
        this.e.a8.exportPathData(a, this.c8, "upperShape", ["Upper"]);
        this.e.a8.exportPathData(a, this.c6, "translucentShape", ["Translucent"]);
    };
    RadialLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pf = a;
        this.e.gy = 3;
        this.e.gz = 1;
        this.e.g0 = 4;
        this.e.e9 = false;
    };
    RadialLineSeriesView.$t = markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
}(AnchoredRadialSeriesView));
export { RadialLineSeriesView };
